@@ -9,17 +9,14 @@ use Weed::Object;
 use Weed::Message;
 
 use Weed::FieldDefinition;
-
 use Weed::Field;
 use Weed::ArrayField;
-
 use Weed::FieldTypes;
+use Weed::Tie::Field;
 
 use Weed::Constants;
 
 use Weed::BaseNode;
 
-use Weed::Components::Core::Node;
-
 1;
 __END__
