@@ -1,32 +1,22 @@
 package Weed::FieldTypes;
 use Weed::Perl;
 
-our $VERSION = '0.01';
-
-# ScalarFieldTypes
 use Weed::FieldTypes::SFBool;
-use Weed::FieldTypes::SFDouble;
-use Weed::FieldTypes::SFFloat;
-use Weed::FieldTypes::SFInt32;
-use Weed::FieldTypes::SFString;
-use Weed::FieldTypes::SFTime;
-
-# VectorFieldTypes
 use Weed::FieldTypes::SFColor;
 use Weed::FieldTypes::SFColorRGBA;
+use Weed::FieldTypes::SFDouble;
+use Weed::FieldTypes::SFFloat;
+use Weed::FieldTypes::SFImage;
+use Weed::FieldTypes::SFInt32;
+use Weed::FieldTypes::SFNode;
 use Weed::FieldTypes::SFRotation;
+use Weed::FieldTypes::SFString;
+use Weed::FieldTypes::SFTime;
 use Weed::FieldTypes::SFVec2d;
 use Weed::FieldTypes::SFVec2f;
 use Weed::FieldTypes::SFVec3d;
 use Weed::FieldTypes::SFVec3f;
-use Weed::FieldTypes::SFVec4d;
-use Weed::FieldTypes::SFVec4f;
 
-# SpecialFieldTypes
-use Weed::FieldTypes::SFImage;
-use Weed::FieldTypes::SFNode;
-
-# MultiFieldTypes
 use Weed::FieldTypes::MFBool;
 use Weed::FieldTypes::MFColor;
 use Weed::FieldTypes::MFColorRGBA;
@@ -42,8 +32,6 @@ use Weed::FieldTypes::MFVec2d;
 use Weed::FieldTypes::MFVec2f;
 use Weed::FieldTypes::MFVec3d;
 use Weed::FieldTypes::MFVec3f;
-use Weed::FieldTypes::MFVec4d;
-use Weed::FieldTypes::MFVec4f;
 
 1;
 __END__
