@@ -1,14 +1,12 @@
 package Weed::FieldTypes::SFBool;
 
-our $VERSION = '0.009';
-
 use Weed 'SFBool : X3DField { FALSE }';
 
-use base 'Weed::BaseFieldTypes::Scalar';
+use base 'Weed::FieldTypes::BaseFieldTypes::SFNumber';
 
 sub setValue {
 	my ( $this, $value ) = @_;
-	$this->X3DField::setValue( defined $value ? ($value ? YES: NO) : $this->getDefaultValue );
+	$this->X3DField::setValue( $value ? YES: NO );
 }
 
 sub toString { $_[0]->getValue ? X3DGenerator->TRUE: X3DGenerator->FALSE }
