@@ -1,50 +1,9 @@
 package Weed::Values::Vec4;
-
-use strict;
-use warnings;
-
-use Weed::Math ();
-
-#use Exporter;
-
-our $VERSION = '0.3449';
+use Weed::Perl;
 
 use base 'Weed::Values::Vector';
 
-use overload
-  #"&", "^", "|",
-
-  #'>>=' => sub { @{ $_[0] } = CORE::reverse @{ $_[0] } if $_[1] & 1; $_[0] },
-  #'<<=' => sub { @{ $_[0] } = CORE::reverse @{ $_[0] } if $_[1] & 1; $_[0] },
-
-  #"!" => sub { !$_[0]->length },
-
-  '+='  => \&_add,
-  '-='  => \&_subtract,
-  '*='  => \&_multiply,
-  '/='  => \&_divide,
-  '**=' => \&__pow,
-  '%='  => \&__mod,
-  #".=", # not posible
-  "x=" => \&_cross,
-
-  '+'  => 'add',
-  '-'  => 'subtract',
-  '*'  => 'multiply',
-  '/'  => 'divide',
-  '**' => \&_pow,
-  '%'  => \&_mod,
-  '.'  => 'dot',
-  "x"  => 'cross',
-
-  #"atan2", "cos", "sin", "exp", "log", "sqrt", "int"
-
-  #"<>"
-
-  #'${}', '@{}', '%{}', '&{}', '*{}'.
-
-  #"nomethod", "fallback",
-  ;
+use overload "x" => 'cross';
 
 use constant getDefaultValue => [ 0, 0, 0, 0 ];
 
@@ -86,14 +45,14 @@ sub add {
 	] );
 }
 
-sub _add {
+use overload '+=' => sub {
 	my ( $a, $b ) = @_;
 	$a->[0] += $b->[0];
 	$a->[1] += $b->[1];
 	$a->[2] += $b->[2];
 	$a->[3] += $b->[3];
 	return $a;
-}
+};
 
 sub subtract {
 	my ( $a, $b, $r ) = @_;
@@ -112,14 +71,14 @@ sub subtract {
 	  ;
 }
 
-sub _subtract {
+use overload '-=' => sub {
 	my ( $a, $b ) = @_;
 	$a->[0] -= $b->[0];
 	$a->[1] -= $b->[1];
 	$a->[2] -= $b->[2];
 	$a->[3] -= $b->[3];
 	return $a;
-}
+};
 
 sub multiply {
 	my ( $a, $b ) = @_;
@@ -139,7 +98,7 @@ sub multiply {
 	  ] );
 }
 
-sub _multiply {
+use overload '*=' => sub {
 	my ( $a, $b ) = @_;
 	if ( ref $b ) {
 		$a->[0] *= $b->[0];
@@ -153,7 +112,7 @@ sub _multiply {
 		$a->[3] *= $b;
 	}
 	return $a;
-}
+};
 
 sub divide {
 	my ( $a, $b, $r ) = @_;
@@ -178,7 +137,7 @@ sub divide {
 	  ] );
 }
 
-sub _divide {
+use overload '/=' => sub {
 	my ( $a, $b ) = @_;
 	if ( ref $b ) {
 		$a->[0] /= $b->[0];
@@ -192,11 +151,9 @@ sub _divide {
 		$a->[3] /= $b;
 	}
 	return $a;
-}
+};
 
-#mod
-#cut
-sub _mod {
+sub mod {
 	my ( $a, $b, $r ) = @_;
 	return ref $b ?
 	  $a->new( [
@@ -219,7 +176,7 @@ sub _mod {
 	  ] );
 }
 
-sub __mod {
+use overload '%=' => sub {
 	my ( $a, $b ) = @_;
 	if ( ref $b ) {
 		$a->[0] = Math::fmod( $a->[0], $b->[0] );
@@ -233,26 +190,33 @@ sub __mod {
 		$a->[3] = Math::fmod( $a->[3], $b );
 	}
 	return $a;
-}
+};
 
-sub _pow {
-	my ( $a, $b ) = @_;
+sub pow {
+	my ( $a, $b, $r ) = @_;
 	return $a->new( [
-			$a->[0]**$b,
-			$a->[1]**$b,
-			$a->[2]**$b,
-			$a->[3]**$b,
+			$r ? (
+				$b**$a->[0],
+				$b**$a->[1],
+				$b**$a->[2],
+				$b**$a->[3],
+			  ) : (
+				$a->[0]**$b,
+				$a->[1]**$b,
+				$a->[2]**$b,
+				$a->[3]**$b,
+			  )
 	] );
 }
 
-sub __pow {
+use overload '**=' => sub {
 	my ( $a, $b ) = @_;
 	$a->[0]**= $b;
 	$a->[1]**= $b;
 	$a->[2]**= $b;
 	$a->[3]**= $b;
 	return $a;
-}
+};
 
 sub dot {
 	my ( $a, $b, $r ) = @_;
@@ -279,7 +243,7 @@ sub cross {
 	);
 }
 
-sub _cross {
+use overload "x=" => sub {
 	my ( $a, $b ) = @_;
 
 	my ( $a0, $a1, $a2, $a3 ) = @$a;
@@ -291,16 +255,16 @@ sub _cross {
 	$a->[3] = ( $a1 * $b0 - $a0 * $b1 ) + ( $a3 * $b0 - $a0 * $b3 ) + ( $a3 * $b1 - $a1 * $b3 );
 
 	return $a;
-}
+};
 
-sub length {
-	my ($a) = @_;
-	return sqrt(
-		$a->[0] * $a->[0] +
-		  $a->[1] * $a->[1] +
-		  $a->[2] * $a->[2] +
-		  $a->[3] * $a->[3]
-	);
-}
+# sub length {
+# 	my ($a) = @_;
+# 	return sqrt(
+# 		$a->[0] * $a->[0] +
+# 		  $a->[1] * $a->[1] +
+# 		  $a->[2] * $a->[2] +
+# 		  $a->[3] * $a->[3]
+# 	);
+# }
 
 1;
