@@ -1,13 +1,9 @@
 package Weed::Values::Vector;
+use Weed::Perl;
 
-use strict;
-use warnings;
-
-our $VERSION = '1.7292';
-
-use Carp       ();
-use Weed::Math ();
-use Scalar::Util qw(reftype);
+use Carp         ();
+use Weed::Math   ();
+use Scalar::Util ();
 
 use overload
   '=' => 'copy',
@@ -16,12 +12,6 @@ use overload
   'int'  => sub { $_[0]->new( [ map { CORE::int($_) } @{ $_[0] } ] ) },
   "0+"   => 'length',
 
-  '~' => sub { $_[0]->new( [ map { ~$_ } @{ $_[0] } ] ) },
-
-  "&" => \&_and,
-  "|" => \&_or,
-  "^" => \&_xor,
-
   '==' => sub { "$_[0]" eq $_[1] },
   '!=' => sub { "$_[0]" ne $_[1] },
   '<=>' => sub { $_[2] ? $_[1] <=> $_[0]->length : $_[0]->length <=> $_[1] },
@@ -30,13 +20,28 @@ use overload
   'ne' => sub { "$_[0]" ne $_[1] },
   'cmp' => sub { $_[2] ? $_[1] cmp $_[0]->length : $_[0]->length cmp $_[1] },
 
+  '~' => sub { $_[0]->new( [ map { ~$_ } @{ $_[0] } ] ) },
+
   'neg' => 'negate',
 
-  '<<' => \&_lshift,
-  '>>' => \&_rshift,
+  '+'  => 'add',
+  '-'  => 'subtract',
+  '*'  => 'multiply',
+  '/'  => 'divide',
+  '%'  => 'mod',
+  '**' => 'pow',
+  '.'  => 'dot',
 
   'abs' => sub { $_[0]->new( [ map { CORE::abs($_) } @{ $_[0] } ] ) },
 
+  #"atan2", "cos", "sin", "exp", "log", "sqrt"
+
+  #"<>"
+
+  #'${}', '@{}', '%{}', '&{}', '*{}'.
+
+  #"nomethod", "fallback",
+
   '""' => 'toString',
   ;
 
@@ -45,23 +50,19 @@ sub new {
 	my $class = ref($self) || $self;
 	my $this  = bless [ @{ $self->getDefaultValue } ], $class;
 
-	if ( 0 == @_ ) {
-		# No arguments, default to standard
-		return $this;
+	if ( @_ == 1 && ref $_[0] ) {
+		if ( Scalar::Util::reftype( $_[0] ) eq 'ARRAY' ) {
+			$this->setValue( @{ $_[0] } );
+		}
+		else {
+			$this->setValue(@_);
+		}
 	}
-	elsif ( 1 == @_ && ref $_[0] && Scalar::Util::reftype( $_[0] ) eq 'ARRAY' ) {
-		$this->setValue( @{ $_[0] } );
-		return $this;
-	}
-	elsif ( @_ > 0 ) {    # x,y
+	elsif (@_) {
 		$this->setValue(@_);
-		return $this;
-	}
-	else {
-		warn("Don't understand arguments passed to new()");
 	}
 
-	return;
+	return $this;
 }
 
 sub copy { $_[0]->new( $_[0]->getValue ) }
@@ -76,39 +77,7 @@ sub setValue {
 	return;
 }
 
-sub _lshift {
-	my ( $a, $b, $r ) = @_;
-	$r ? (
-		ref $b ?
-		  $b->new( [ map { $b->[$_] << $a->[$_] } ( 0 .. $#{ $b->getDefaultValue } ) ] )
-		:
-		  $b->new( [ map { $_ << $a } @$b ] )
-	  ) : (
-		ref $b ?
-		  $a->new( [ map { $a->[$_] << $b->[$_] } ( 0 .. $#{ $a->getDefaultValue } ) ] )
-		:
-		  $a->new( [ map { $_ << $b } @$a ] )
-
-	  )
-}
-
-sub _rshift {
-	my ( $a, $b, $r ) = @_;
-	$r ? (
-		ref $b ?
-		  $b->new( [ map { $b->[$_] >> $a->[$_] } ( 0 .. $#{ $b->getDefaultValue } ) ] )
-		:
-		  $b->new( [ map { $_ >> $a } @$b ] )
-	  ) : (
-		ref $b ?
-		  $a->new( [ map { $a->[$_] >> $b->[$_] } ( 0 .. $#{ $a->getDefaultValue } ) ] )
-		:
-		  $a->new( [ map { $_ >> $b } @$a ] )
-
-	  )
-}
-
-sub _and {
+use overload "&" => sub {
 	my ( $a, $b, $r ) = @_;
 	$r ? (
 		ref $b ?
@@ -122,9 +91,9 @@ sub _and {
 		  $a->new( [ map { $_ & $b } @$a ] )
 
 	  )
-}
+};
 
-sub _or {
+use overload "|" => sub {
 	my ( $a, $b, $r ) = @_;
 	$r ? (
 		ref $b ?
@@ -138,9 +107,9 @@ sub _or {
 		  $a->new( [ map { $_ | $b } @$a ] )
 
 	  )
-}
+};
 
-sub _xor {
+use overload "^" => sub {
 	my ( $a, $b, $r ) = @_;
 	$r ? (
 		ref $b ?
@@ -154,14 +123,46 @@ sub _xor {
 		  $a->new( [ map { $_ ^ $b } @$a ] )
 
 	  )
-}
+};
+
+use overload "<<" => sub {
+	my ( $a, $b, $r ) = @_;
+	$r ? (
+		ref $b ?
+		  $b->new( [ map { $b->[$_] << $a->[$_] } ( 0 .. $#{ $b->getDefaultValue } ) ] )
+		:
+		  $b->new( [ map { $_ << $a } @$b ] )
+	  ) : (
+		ref $b ?
+		  $a->new( [ map { $a->[$_] << $b->[$_] } ( 0 .. $#{ $a->getDefaultValue } ) ] )
+		:
+		  $a->new( [ map { $_ << $b } @$a ] )
+
+	  )
+};
+
+use overload ">>" => sub {
+	my ( $a, $b, $r ) = @_;
+	$r ? (
+		ref $b ?
+		  $b->new( [ map { $b->[$_] >> $a->[$_] } ( 0 .. $#{ $b->getDefaultValue } ) ] )
+		:
+		  $b->new( [ map { $_ >> $a } @$b ] )
+	  ) : (
+		ref $b ?
+		  $a->new( [ map { $a->[$_] >> $b->[$_] } ( 0 .. $#{ $a->getDefaultValue } ) ] )
+		:
+		  $a->new( [ map { $_ >> $b } @$a ] )
+
+	  )
+};
 
 sub rotate {
-	my $n = -$_[1] % @{ $_[0]->getDefaultValue };
+	my $n = -$_[1] % $_[0]->size;
 
 	if ($n) {
 		my $vec = [ $_[0]->getValue ];
-		splice @$vec, @{ $_[0]->getDefaultValue } - $n, $n, splice( @$vec, 0, $n );
+		splice @$vec, $_[0]->size - $n, $n, splice( @$vec, 0, $n );
 		return $_[0]->new($vec);
 	}
 
@@ -177,11 +178,19 @@ sub sum {
 	return $sum;
 }
 
+sub squarednorm {
+	my $squarednorm = 0;
+	$squarednorm += $_ * $_ foreach @{ $_[0] };
+	return $squarednorm;
+}
+
 sub normalize { $_[0] / $_[0]->length }
 
-sub toString {
-	return join " ", $_[0]->getValue;
-}
+sub length { CORE::sqrt( $_[0]->squarednorm ) }
+
+sub size { scalar @{ $_[0]->getDefaultValue } }
+
+sub toString { join " ", $_[0]->getValue }
 
 1;
 __END__
